@@ -24,16 +24,17 @@
 
 "bgpllm" <-
 function(X, Z, XX=NULL, bprior="bflat", corr="expsep", gamma=c(10,0.2,0.7),
-         BTE=c(1000,4000,2), R=1, m0r1=FALSE, pred.n=TRUE, ds2x=FALSE, ego=FALSE)
+         BTE=c(1000,4000,2), R=1, m0r1=FALSE, pred.n=TRUE, ds2x=FALSE,
+         ego=FALSE)
 {
-	n <- dim(X)[1]
-	if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 }
-        else { d <- dim(X)[2] }
-	params <- tgp.default.params(d+1)
-	params$bprior <- bprior
-	params$corr <- corr
-	params$gamma <- gamma
-	params$tree <- c(0,0,10)	# no tree
-	return(tgp(X,Z,XX,BTE,R,m0r1,FALSE,params,pred.n,ds2x,ego))
+  n <- dim(X)[1]
+  if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 }
+  else { d <- dim(X)[2] }
+  params <- tgp.default.params(d+1)
+  params$bprior <- bprior
+  params$corr <- corr
+  params$gamma <- gamma
+  params$tree <- c(0,0,10)	# no tree
+  return(tgp(X,Z,XX,BTE,R,m0r1,FALSE,params,pred.n,ds2x,ego))
 }
 
