@@ -27,13 +27,14 @@ function(X, Z, XX=NULL, bprior="bflat", corr="expsep", tree=c(0.25,2,10),
 	BTE=c(2000,7000,2), R=1, m0r1=FALSE, linburn=FALSE, pred.n=TRUE,
         ds2x=FALSE, ego=FALSE)
 {
-	n <- dim(X)[1]
-	if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 } else { d <- dim(X)[2] }
-	params <- tgp.default.params(d+1)
-	params$bprior <- bprior
-	params$corr <- corr
-	params$tree <- tree;
-	params$gamma <- c(0,0.2,0.7)	# no llm
-	return(tgp(X,Z,XX,BTE,R,m0r1,linburn,params,pred.n,ds2x,ego))
+  n <- dim(X)[1]
+  if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 }
+  else { d <- dim(X)[2] }
+  params <- tgp.default.params(d+1)
+  params$bprior <- bprior
+  params$corr <- corr
+  params$tree <- tree;
+  params$gamma <- c(0,0.2,0.7)	# no llm
+  return(tgp(X,Z,XX,BTE,R,m0r1,linburn,params,pred.n,ds2x,ego))
 }
 
