@@ -28,10 +28,10 @@
 int predict_full_linear(unsigned int n, unsigned int nn, unsigned int col, 
 			 double *z, double *zz, double **F, double **FF, double *bmu, 
 			double s2, double  **Vb, double **Ds2xy, double *ego, 
-			 double nug, int err, unsigned short *state);
+			 double nug, int err, void *state);
 int predict_full_noK(unsigned int n1, unsigned int n2, unsigned int col, double * zz, 
 	double * z, double **Ds2xy, double **F, double **T, double tau2, 
-	double **FF, double *b, double ss2, double nug, int err, unsigned short *state);
+	double **FF, double *b, double ss2, double nug, int err, void *state);
 void predict_noK(unsigned int n1, unsigned int col, double *zmean, double *zs2, double **F, 
 		 double *b, double s2, double **Vb);
 void delta_sigma2_noK(double *Ds2xy, unsigned int n1, unsigned int n2, unsigned int col, 
